#ifndef _NEVIN_HERMITE_
#define _NEVIN_HERMITE_

#include "curve.h"

#define ARROW_HEAD_LENGTH 7

enum Continuity {G0, G1, C1};			// enumerated type to represent levels of continuity.

void drawArrow(GLfloat *, GLfloat *);					// Draw an arrow starting at the first point
											// and ending at the second.
class hermite : public curve
{	public:
		// Constructors:  (no destructor, as the parent is sufficient.)
		hermite();
		hermite(unsigned int);
		hermite(unsigned int, GLfloat*);
		
		// Functions to read values from protected data:
		Continuity getContinuity() const;			// Access continuity of curve
		int howManySegments() const;			// Returns number of segments

		// Functions to change values of protected data:
		virtual void set(unsigned int, coordEnum, GLfloat);	// Set a single X, Y, or Z value
		virtual void set(unsigned int, GLfloat*);		// Set X, Y, and Z aspects of a coordinate
		virtual void setAll(GLfloat*);				// Set values of control points.
		virtual void setAll(unsigned int, GLfloat*);		// Set # of control points and their values
		virtual void addPoint();					// Add point to end of curve, on origin
		virtual void addPoint(GLfloat*);				// Add point to end, specify its position		
		void setContinuity(Continuity);				// Set continuity of curve
		
		// Functions which provide information about the specified curve:
		virtual GLfloat getAtTimeT(coordEnum, GLfloat);	
		virtual void getAtTimeT(GLfloat, GLfloat*);		// Get value at specific time.
		virtual void draw();						// Draw the curve				
				
	protected:
		virtual void enforceCont(unsigned int, int);
		virtual void calcCoeffs();
		Continuity cont;										// continuity of join
};

#endif